@@ -206,7 +206,7 @@ class Postgres_Handler:
             table_name = kwargs[self.table_name_key]
             
             #Begining of the SQL query
-            query_string= f"UPDATE {table_name} SET"
+            query_string= "UPDATE {table_name} SET".format(table_name = sql.Identifier(kwargs[self.table_name_key]))
             
             for key, value in kwargs.items():
                 if key.lower() == id_key.lower() or key.lower() == self.table_name_key: continue
